@@ -126,31 +126,26 @@ load_image (gchar *fname,
 	g_free (tmp);
 
 
-	/* Just think of this as an if statement, but we want to use break. */
-	while (!g_file_test (fn, G_FILE_TEST_EXISTS)) {
+	if (!g_file_test (fn, G_FILE_TEST_EXISTS)) {
 		char * message;
 		GtkWidget * w;
-
-		/* ball.png was replaced with balls.svg. */
-		if (g_utf8_collate (fname, "ball.png") == 0) {
-			tmp = g_build_filename ("glines", "balls.svg", NULL);
-			fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
-			g_free (tmp);
-			if (g_file_test (fn, G_FILE_TEST_EXISTS))
-				break;
+		
+		tmp = g_build_filename ("glines", "balls.svg", NULL);
+		fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
+		g_free (tmp);
+		if (!g_file_test (fn, G_FILE_TEST_EXISTS)) {
+			message = g_strdup_printf (_("Five or More could not find image file:\n%s\n\n"
+						     "Please check Five or More is installed correctly."), fn);
+			w = gtk_message_dialog_new (GTK_WINDOW (app),
+						    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						    GTK_MESSAGE_ERROR,
+						    GTK_BUTTONS_OK,
+						    message,
+						    NULL);
+			gtk_dialog_run (GTK_DIALOG (w));	
+			g_free (message);
+			exit (1);
 		}
-
-		message = g_strdup_printf (_("Five or More could not find image file:\n%s\n\n"
-					     "Please check Five or More is installed correctly."), fn);
-		w = gtk_message_dialog_new (GTK_WINDOW (app),
-					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_OK,
-					    message,
-					    NULL);
-		gtk_dialog_run (GTK_DIALOG (w));	
-		g_free (message);
-		exit (1);
 	}
 
 	image = gdk_pixbuf_new_from_file (fn, NULL);
@@ -166,29 +161,15 @@ load_image (gchar *fname,
 static void
 refresh_pixmaps (void)
 {
-	static GdkGC * grid_gc = NULL;
 	GdkGC * gc;
-        GdkColormap *cmap;
-        GdkColor color;
 	GdkPixbuf *ball_pixbuf;
-	gint i;
 
 	/* Since we get called both by configure and after loading an image.
 	 * it is possible the pixmaps aren't initialised. If they aren't
 	 * we don't do anything. */
-
 	if (!ball_pixmap)
 		return;
 
-	if (!grid_gc) {
-		grid_gc = gdk_gc_new (draw_area->window);
-
-		gdk_color_parse ("#525F6C", &color);
-		cmap = gtk_widget_get_colormap (draw_area);
-		gdk_colormap_alloc_color (cmap, &color, FALSE, TRUE);
-		gdk_gc_set_foreground (grid_gc, &color);
-	}
-
 	ball_pixbuf = gdk_pixbuf_scale_simple (raw_pixbuf, 4*boxsize, 
 					       7*boxsize, 
 					       GDK_INTERP_BILINEAR);
@@ -197,19 +178,12 @@ refresh_pixmaps (void)
 	gdk_gc_set_foreground (gc, &backgnd.color);
 
 	gdk_draw_rectangle (ball_pixmap, gc, TRUE, 0, 0, 4*boxsize, 7*boxsize);
-	for (i=0; i<4; i++) 
-		gdk_draw_line (ball_pixmap, grid_gc, i*boxsize, 0, i*boxsize,
-			       7*boxsize);
-	for (i=0; i<7; i++)
-		gdk_draw_line (ball_pixmap, grid_gc, 0, i*boxsize, 4*boxsize,
-			       i*boxsize);
 
 	gdk_draw_pixbuf (ball_pixmap, gc,
 			 ball_pixbuf, 0, 0, 0, 0, boxsize*4, boxsize*7,
 			 GDK_RGB_DITHER_NORMAL, 0, 0);
+
 	gdk_draw_rectangle (blank_pixmap, gc, TRUE, 0, 0, boxsize, boxsize);
-	gdk_draw_line (blank_pixmap, grid_gc, 0, 0, 0, boxsize);
-	gdk_draw_line (blank_pixmap, grid_gc, 0, 0, boxsize, 0);
 
 	g_object_unref (ball_pixbuf);
 	g_object_unref (gc);
@@ -277,7 +251,6 @@ set_inmove (int i)
  	}
 }
 
-
 static void
 reset_game (void)
 {
@@ -318,7 +291,6 @@ start_game (void)
 	set_inmove (0);
 }
 
- 
 static void
 reset_pathsearch (void)
 {
@@ -393,18 +365,29 @@ game_over (void)
 	return;
 }
 
+static int spaces_left (void)
+{
+	int i,j;
+
+	j = 0;
+
+	for (i=0; i<FIELDSIZE*FIELDSIZE; i++) {
+		if (field[i].color == 0)
+			j++;
+	}
+
+	return j;
+}
+
 static int
 check_gameover (void)
 {
-	int i = 0;
-	while ((i < FIELDSIZE * FIELDSIZE) && field[i].color != 0)
-		i++;
-	if (i == FIELDSIZE * FIELDSIZE)
-	{
-		game_over ();
-		return -1;
-	}
-	return i;
+	if (spaces_left ()> 0)
+		return 1;
+
+	game_over ();
+
+	return -1;
 }
 
 int
@@ -583,11 +566,42 @@ button_press_event (GtkWidget *widget, GdkEvent *event)
 	return TRUE;
 }
 
+static void
+draw_grid (void)
+{
+	static GdkGC *grid_gc;
+	guint w, h;
+	guint i;
+
+	w = draw_area->allocation.width;
+	h = draw_area->allocation.height;
+
+	if (!grid_gc) {
+		GdkColormap *cmap;
+		GdkColor color;
+
+		grid_gc = gdk_gc_new (draw_area->window);
+
+		gdk_color_parse ("#525F6C", &color);
+		cmap = gtk_widget_get_colormap (draw_area);
+		gdk_colormap_alloc_color (cmap, &color, FALSE, TRUE);
+		gdk_gc_set_foreground (grid_gc, &color);
+	}
+
+	for (i = boxsize; i < w; i = i + boxsize)
+		gdk_draw_line (draw_area->window, grid_gc, i, 0, i, h);
+
+	for (i = boxsize; i < h; i = i + boxsize)
+		gdk_draw_line (draw_area->window, grid_gc, 0, i, w, i);
+
+	gdk_draw_rectangle (draw_area->window, grid_gc, FALSE, 0, 0, w - 1, h - 1);
+}
+
 /* Redraw a part of the field */
 static gint
 field_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp)
 {
-	GdkWindow * window = widget->window;
+	GdkWindow *window = widget->window;
 	GdkGC *gc;
 	guint x_start, x_end, y_start, y_end, i, j, idx;
 
@@ -630,65 +644,71 @@ field_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp)
 	}
         g_object_unref (gc);
 
+	draw_grid ();
+
 	return FALSE;
 }
 
-static void
-kill_tagged(GtkWidget *widget, int num)
-{
-	int i;
-
-	for (i = 0; i <= num; i++)
-		{
-			field[field[i].pathsearch].color = 0;
-			field[field[i].pathsearch].phase = 0;
-			field[field[i].pathsearch].active = 0;
-			draw_box (widget, field[i].pathsearch % 9,
-				  field[i].pathsearch / 9);
-		}
-}
-
 static int
 addscore (int num)
 {
+	gchar string[20];
 	int i = 0;
-	
+	int retval;
+
 	while ((sctab[i].num != num) && (sctab[i].num != 0))
 		i++;
 	if (sctab[i].num == 0)
-		return 10 + (int) pow ((double)2.0, (double)(num - 5));
-	return (sctab[i].score);
+		retval = 10 + (int) pow ((double)2.0, (double)(num - 5));
+	else
+		retval = sctab[i].score;
+
+	score += retval;
+	g_snprintf (string, 19, "%d", score);
+	gtk_label_set_text (GTK_LABEL (scorelabel), string);		
+
+	return retval;
 }
 	
 
-static int
-check_goal (GtkWidget *widget, int num)
+static void tag_list (int * list, int len)
 {
-	int count = 0;
+	int i;
+
+	for (i=0; i<len; i++)
+		field[list[i]].tag = 1;
+}
+
+static int
+find_lines (int num)
+{
+	int count = 1;
 	int subcount = 0;
 	int x = num%9;
 	int y = num/9;
-
-	field[0].pathsearch = num;
+	int list[FIELDSIZE];
 
 	/* Horizontal */
 
 	x++;
 	while ((x <= FIELDSIZE - 1) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		x++;
 	}
 	x = num % 9 - 1;
 	while ((x >= 0) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		x--;
 	}
-	if (subcount >= 4)
-		count +=subcount;
+	if (subcount >= 4) {
+		field[num].tag = 1;
+		tag_list (list, subcount);
+		count += subcount;
+	}
 	subcount = 0;
 
 	/* Vertical */
@@ -697,19 +717,22 @@ check_goal (GtkWidget *widget, int num)
 	y++;
 	while ((y <= FIELDSIZE - 1) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y++;
 	}
 	y = num / 9 - 1;
 	while ((y >= 0) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y--;
 	}
-	if (subcount >= 4)
-		count +=subcount;
+	if (subcount >= 4) {
+		field[num].tag = 1;
+		tag_list (list, subcount);
+		count += subcount;
+	}
 	subcount = 0;
 	
 	/* Diagonal ++*/
@@ -718,8 +741,8 @@ check_goal (GtkWidget *widget, int num)
 	y = num/9 + 1;
 	while ((y <= FIELDSIZE - 1) && (x <= FIELDSIZE - 1) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y++;
 		x++;
 	}
@@ -727,13 +750,16 @@ check_goal (GtkWidget *widget, int num)
 	y = num / 9 - 1;
 	while ((y >= 0) && (x >= 0) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y--;
 		x--;
 	}
-	if (subcount >= 4)
+	if (subcount >= 4) {
+		field[num].tag = 1;
+		tag_list (list, subcount);
 		count +=subcount;
+	}
 	subcount = 0;
 
 	/* Diagonal +-*/
@@ -742,8 +768,8 @@ check_goal (GtkWidget *widget, int num)
 	y = num / 9 - 1;
 	while ((y >= 0) && (x <= FIELDSIZE - 1) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y--;
 		x++;
 	}
@@ -751,30 +777,64 @@ check_goal (GtkWidget *widget, int num)
 	y = num / 9 + 1;
 	while ((y <= FIELDSIZE - 1) && (x >= 0) && (field[x + y*9].color == field[num].color))
 	{
+		list[subcount] = x + y*9;
 		subcount++;
-		field[count + subcount].pathsearch = x + y*9;
 		y++;
 		x--;
 	}
-	if (subcount >= 4)
+	if (subcount >= 4) {
+		field[num].tag = 1;
+		tag_list (list, subcount);
 		count +=subcount;
-	subcount = 0;
+	}
 
-	/* Finish */
-	
-	if (count >= 4)
+	return count;
+}
+
+static void clear_tags (void)
+{
+	int i;
+
+	for (i=0; i<FIELDSIZE*FIELDSIZE; i++)
+		field[i].tag = 0;
+}
+
+static int kill_tags (GtkWidget * widget)
+{
+	int i,j;
+
+	j = 0;
+	for (i = 0; i <FIELDSIZE*FIELDSIZE; i++) {
+		if (field[i].tag == 1) {
+			j++;
+			field[i].color = 0;
+			field[i].phase = 0;
+			field[i].active = 0;
+			draw_box (widget, i % 9, i / 9);
+		}
+	}
+
+	return j;
+}
+
+static gboolean check_goal (GtkWidget * w, int target)
+{
+	gboolean lines_cleared;
+	int count;
+
+	clear_tags ();
+
+	count = find_lines (target);
+	lines_cleared = count >= 5;
+
+	if (lines_cleared)
 	{
-		char string[20];
-
-		kill_tagged (widget, count);
-		score += addscore (count+1);
-		g_snprintf (string, 19, "%d", score);
-		gtk_label_set_text (GTK_LABEL (scorelabel), string);
-
-		subcount = 1;
+		kill_tags (w);
+		addscore (count);
 	}
 	reset_pathsearch ();
-	return subcount;
+
+	return lines_cleared;
 }
 
 gint
@@ -821,15 +881,27 @@ animate (gpointer gp)
 			reset_pathsearch ();
 			if (!check_goal (widget, newactive))
 			{
-				for (x = 0; x < 3; x++)
+				gboolean fullline;
+				int balls[3];
+				int spaces;
+
+				clear_tags ();
+				fullline = FALSE;
+				spaces = spaces_left ();
+				if (spaces > 3)
+					spaces = 3;
+				for (x = 0; x < spaces; x++)
 				{
 					int tmp = init_new_balls (1, x);
 					draw_box (widget, tmp % FIELDSIZE,
 						   tmp / FIELDSIZE);
-					check_goal (widget, tmp);
-					if (check_gameover () == -1)
-						return FALSE;
+					balls[x] = tmp;
+					fullline = (find_lines (balls[x]) >= 5) || fullline;
 				}
+				if (fullline) 
+					addscore (kill_tags (widget));
+				if (check_gameover () == -1)
+					return FALSE;
 				init_preview ();
 				draw_preview ();
 			}
