@@ -33,6 +33,7 @@
 #include "sound.h"
 #include "properties.h"
 #include "game.h"
+#include "cursors.h"
 
 /**********************************************************************/
 /* Exported Variables                                                 */
@@ -162,6 +163,7 @@ int
 main (int argc, char *argv[])
 {
   GtkWidget      *stbar;
+  GtkWidget      *errordialog;
   GnomeClient    *client;
   struct timeval tv;
   gint           i;
@@ -205,12 +207,16 @@ main (int argc, char *argv[])
   gnome_app_set_statusbar (GNOME_APP (app), stbar);
 
   create_game_menus ();
+  make_cursors ();
 
-  gtk_widget_push_colormap (gdk_rgb_get_colormap ());
   game_area = gtk_drawing_area_new ();
-  gtk_widget_pop_colormap ();
+  gtk_widget_add_events (game_area, GDK_BUTTON_PRESS_MASK |
+			 GDK_POINTER_MOTION_MASK);
+  g_signal_connect (G_OBJECT (game_area), "button-press-event",
+		    G_CALLBACK (mouse_cb), NULL);
+  g_signal_connect (G_OBJECT (game_area), "motion-notify-event",
+		    G_CALLBACK (move_cb), NULL);
   gnome_app_set_contents (GNOME_APP (app), game_area);
-  gtk_widget_realize (game_area);
   gtk_widget_set_size_request (GTK_WIDGET (game_area), 
                                TILE_WIDTH * GAME_WIDTH,
                                TILE_HEIGHT * GAME_HEIGHT);
@@ -221,9 +227,21 @@ main (int argc, char *argv[])
     gtk_window_move (GTK_WINDOW (app), session_xpos, session_ypos);
   }
 
-  gtk_widget_show (app);
+  if (!load_game_configs ()) {
+    /* Oops, no configs, we probably haven't been installed properly. */
+    errordialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
+                                          GTK_BUTTONS_OK,
+                                          "<b>%s</b>\n\n%s",
+                                          _("No game data could be found."),
+                                          _("The program GNOME Robots was unable to find any valid game configuration files. Please check that the program is installed correctly."));
+    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (errordialog)->label), TRUE);
+    gtk_window_set_resizable (GTK_WINDOW (errordialog), FALSE);
+    gtk_dialog_run (GTK_DIALOG (errordialog));
+    exit (1);
+  }
 
-  load_game_configs ();
+  gtk_widget_show (app);
+  
   load_game_graphics ();
   load_properties ();
   
@@ -253,8 +271,6 @@ main (int argc, char *argv[])
 
   gtk_main ();
 
-  cleanup_game ();
-
   return 0;
 }
 
