@@ -32,6 +32,10 @@ view_geom_record view_geometry[MAX_TILES];
 /* The number of different tile patterns plus a blank tile at the end. */
 #define NUM_PATTERNS 43
 
+/* Aspect ratio of individual tiles (i.e., height/width).
+ * 1.375 = 64/88 */
+#define ASPECT 1.375
+
 GtkWidget * board = NULL;
 GdkPixmap * buffer = NULL;
 GdkPixmap * tileimages = NULL;
@@ -40,14 +44,16 @@ GdkBitmap * tilemask = NULL;
 
 GdkGC * gc = NULL;
 
+gboolean update_tileimages = TRUE;
 gboolean nowindow = TRUE;
 
 GdkColor bgcolour;
 
 GdkPixbuf * tilepixbuf = NULL;
 
-gint windowwidth;
-gint windowheight;
+static gint windowwidth;
+static gint windowheight;
+gint prior_tilebasewidth = 0;
 gint tilebasewidth = 0;
 gint tilebaseheight = 0;
 gint tileoffsetx;
@@ -69,13 +75,16 @@ gint gridheight;
 
 static void recalculate_sizes (gint width, gint height)
 {
+  gdouble scale;
+
   /* This calculates four things: the size of the complete tile pixmap,
    * the offsets from the edge of the window, the offset for the 3-D effect
    * (i.e. the sides of the tile) and the size of the face of the tile. */
-  tilebasewidth = width / gridwidth;
-  tilebaseheight = height / gridheight;
-  xoffset = tilebasewidth/2;
-  yoffset = tilebaseheight/2;
+  scale = MIN (width/gridwidth, height/(gridheight*ASPECT));
+  tilebasewidth = scale;
+  tilebaseheight = scale*ASPECT;
+  xoffset = (width - (gridwidth-1)*tilebasewidth)/2;
+  yoffset = (height - (gridheight-1)*tilebaseheight)/2;
   tileoffsetx = tilebasewidth/7;
   tileoffsety = tilebaseheight/10;
   tilewidth = tilebasewidth + tileoffsetx;
@@ -90,7 +99,7 @@ static void calculate_tile_positions (void)
   v = view_geometry;
   for (i=0; i<MAX_TILES; i++) {
     v->x = pos[i].x*tilebasewidth/2 + pos[i].layer*tileoffsetx + xoffset;
-    v->y = pos[i].y*tilebaseheight/2 - pos[i].layer*tileoffsety + xoffset;
+    v->y = pos[i].y*tilebaseheight/2 - pos[i].layer*tileoffsety + yoffset;
     v++;
   }
 }
@@ -268,7 +277,7 @@ static void recreate_tile_images (void)
 
   gdk_pixbuf_render_threshold_alpha (fg, tilemask, 0, 0, 0, 0,
                                      tilewidth, tileheight, 128);
-  gdk_draw_pixbuf (tileimages, gc, fg, 0, 0, 0, 0,
+  gdk_draw_pixbuf (tileimages, NULL, fg, 0, 0, 0, 0,
                    tilewidth*NUM_PATTERNS, tileheight*2,
                    GDK_RGB_DITHER_MAX, 0, 0);
 
@@ -284,21 +293,29 @@ void configure_pixmaps (void)
   if (nowindow)
     return;
 
+  prior_tilebasewidth = tilebasewidth;
+
   recalculate_sizes (windowwidth, windowheight);
   calculate_tile_positions ();
 
   if (buffer != NULL) g_object_unref (buffer);
-  if (tileimages != NULL) g_object_unref (tileimages);
-  if (tilemask != NULL) g_object_unref (tilemask);
-  if (tilebuffer != NULL) g_object_unref (tilebuffer);
-
   buffer = gdk_pixmap_new (board->window, windowwidth, windowheight, -1);
-  tileimages = gdk_pixmap_new (board->window, NUM_PATTERNS*tilewidth,
-                               2*tileheight, -1);
-  tilemask = gdk_pixmap_new (NULL, tilewidth, tileheight, 1);
-  tilebuffer = gdk_pixmap_new (board->window, tilewidth, tileheight, -1);
 
-  recreate_tile_images ();
+  /* Recreate the tile images only if the theme or tile size changed. */
+  if ((prior_tilebasewidth != tilebasewidth) || (update_tileimages)) {
+
+    if (tileimages != NULL) g_object_unref (tileimages);
+    if (tilemask != NULL) g_object_unref (tilemask);
+    if (tilebuffer != NULL) g_object_unref (tilebuffer);
+
+    tileimages = gdk_pixmap_new (board->window, NUM_PATTERNS*tilewidth,
+                                 2*tileheight, -1);
+    tilemask = gdk_pixmap_new (NULL, tilewidth, tileheight, 1);
+    tilebuffer = gdk_pixmap_new (board->window, tilewidth, tileheight, -1);
+
+    recreate_tile_images ();
+    update_tileimages = FALSE;
+  }
 }
 
 /* Here is where we create the backing pixmap and set up the tile pixmaps. */
@@ -333,6 +350,10 @@ static void board_click (GtkWidget * w, GdkEventButton * e, gpointer data)
 {
   gint tileno;
 
+  /* Ignore the 2BUTTON and 3BUTTON events. */
+  if (e->type != GDK_BUTTON_PRESS)
+    return;
+
   tileno = find_tile (e->x, e->y);
 
   if (tileno < 0) return;
@@ -373,7 +394,7 @@ gboolean load_images (gchar * file)
   g_free (temp);
 
   if (filename == NULL) {
-    file = "mahjongg/default.svg";
+    file = "mahjongg/default.png";
     filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
                                           file, TRUE, NULL);
     if (filename == NULL) {
@@ -384,6 +405,8 @@ gboolean load_images (gchar * file)
   
   tilepixbuf = gdk_pixbuf_new_from_file (filename, NULL);
   
+  update_tileimages = TRUE;
+  
   if (tileset)
     g_free (tileset);
   tileset = g_strdup (file);
